@@ -8,5 +8,16 @@ from interfaces import IFOConverter, IHTML2FOConverter, IXSLFOConverter
 
 from convert import Converter
 from html2fo import HTML2FOConverter
-from fo2pdf import PDFConverter
-from fo2xfc import DOCXConverter, RTFConverter, ODTConverter, WMLConverter
+from fo2pdf import PDFConverter, xinc_available
+from fo2xfc import DOCXConverter, RTFConverter, ODTConverter, WMLConverter, xfc_available
+
+
+def availableFormats():
+
+    formats = []
+    if xinc_available():
+        formats.append('pdf')
+    if xfc_available():
+        formats.extend(['rtf', 'docx', 'odt', 'wml'])
+
+    return formats
